/**
 * The current action being performed by the CLI. 'none' represents the absence of an action.
 */
export type ToolkitAction = "assembly" | "bootstrap" | "synth" | "list" | "diff" | "deploy" | "rollback" | "watch" | "destroy" | "doctor" | "gc" | "import" | "metadata" | "init" | "migrate";
/**
 * The reporting level of the message.
 * All messages are always reported, it's up to the IoHost to decide what to log.
 */
export type IoMessageLevel = "error" | "result" | "warn" | "info" | "debug" | "trace";
/**
 * A valid message code.
 */
export type IoMessageCode = `CDK_${string}_${"E" | "W" | "I"}${number}${number}${number}${number}`;
/**
 * An IO message emitted.
 */
export interface IoMessage<T> {
	/**
	 * The time the message was emitted.
	 */
	readonly time: Date;
	/**
	 * The recommended log level of the message.
	 *
	 * This is an indicative level and should not be used to explicitly match messages, instead match the `code`.
	 * The level of a message may change without notice.
	 */
	readonly level: IoMessageLevel;
	/**
	 * The action that triggered the message.
	 */
	readonly action: ToolkitAction;
	/**
	 * A short message code uniquely identifying a message type using the format CDK_[CATEGORY]_[E/W/I][0000-9999].
	 *
	 * The level indicator follows these rules:
	 * - 'E' for error level messages
	 * - 'W' for warning level messages
	 * - 'I' for info/debug/trace level messages
	 *
	 * Codes ending in 000 0 are generic messages, while codes ending in 0001-9999 are specific to a particular message.
	 * The following are examples of valid and invalid message codes:
	 * ```ts
	 * 'CDK_ASSETS_I0000'       // valid: generic assets info message
	 * 'CDK_TOOLKIT_E0002'      // valid: specific toolkit error message
	 * 'CDK_SDK_W0023'          // valid: specific sdk warning message
	 * ```
	 *
	 * @see https://github.com/aws/aws-cdk-cli/blob/main/packages/%40aws-cdk/toolkit-lib/CODE_REGISTRY.md
	 */
	readonly code: IoMessageCode;
	/**
	 * The message text.
	 * This is safe to print to an end-user.
	 */
	readonly message: string;
	/**
	 * The data attached to the message.
	 */
	readonly data?: T;
}
/**
 * An IO request emitted.
 */
export interface IoRequest<T, U> extends IoMessage<T> {
	/**
	 * The default response that will be used if no data is returned.
	 */
	readonly defaultResponse: U;
}
export interface IIoHost {
	/**
	 * Notifies the host of a message.
	 * The caller waits until the notification completes.
	 */
	notify<T>(msg: IoMessage<T>): Promise<void>;
	/**
	 * Notifies the host of a message that requires a response.
	 *
	 * If the host does not return a response the suggested
	 * default response from the input message will be used.
	 */
	requestResponse<T, U>(msg: IoRequest<T, U>): Promise<U>;
}
/**
 * Represents a general toolkit error in the AWS CDK Toolkit.
 */
export declare class ToolkitError extends Error {
	/**
	 * Determines if a given error is an instance of ToolkitError.
	 */
	static isToolkitError(x: any): x is ToolkitError;
	/**
	 * Determines if a given error is an instance of AuthenticationError.
	 */
	static isAuthenticationError(x: any): x is AuthenticationError;
	/**
	 * Determines if a given error is an instance of AssemblyError.
	 */
	static isAssemblyError(x: any): x is AssemblyError;
	/**
	 * Determines if a given error is an instance of AssemblyError.
	 */
	static isContextProviderError(x: any): x is ContextProviderError;
	/**
	 * The type of the error, defaults to "toolkit".
	 */
	readonly type: string;
	constructor(message: string, type?: string);
}
/**
 * Represents an authentication-specific error in the AWS CDK Toolkit.
 */
export declare class AuthenticationError extends ToolkitError {
	constructor(message: string);
}
/**
 * Represents an authentication-specific error in the AWS CDK Toolkit.
 */
export declare class AssemblyError extends ToolkitError {
	constructor(message: string);
}
/**
 * Represents an error originating from a Context Provider
 */
export declare class ContextProviderError extends ToolkitError {
	constructor(message: string);
}

export {};
